@@ -181,7 +181,7 @@ html_engine_get_document_color (HTMLEngine *engine)
 				return html_text_get_color_at_index (HTML_TEXT (obj), engine, g_utf8_offset_to_pointer (HTML_TEXT (obj)->text, offset) - HTML_TEXT (obj)->text);
 			} else {
 				HTMLColor *color = html_colorset_get_color (engine->settings->color_set, HTMLTextColor);
-				html_color_ref(color);
+				html_color_ref (color);
 				return color;
 			}
 		}
@@ -321,7 +321,7 @@ set_empty_flow_style (HTMLEngine *e, GtkHTMLFontStyle and_mask, GtkHTMLFontStyle
 	undo->and_mask = and_mask;
 	undo->or_mask = old_or_mask;
 	undo->data.destroy = NULL;
-	html_undo_add_action (e->undo,
+	html_undo_add_action (e->undo, e,
 			      html_undo_action_new ("Set empty paragraph text style", set_empty_flow_style_undo_action,
 						    HTML_UNDO_DATA (undo), html_cursor_get_position (e->cursor),
 						    html_cursor_get_position (e->cursor)), dir);
