@@ -94,7 +94,7 @@ begin (HTMLPainter *painter,
 	gdouble printer_x2, printer_y2;
 	cairo_t *cr;
 #ifdef PRINTER_DEBUG
-	gdouble dash [2];
+	gdouble dash[2];
 #endif
 	printer = HTML_PRINTER (painter);
 	g_return_if_fail (printer);
@@ -113,8 +113,8 @@ begin (HTMLPainter *painter,
 	cairo_rectangle (cr, printer_x1, printer_y1, printer_x2, printer_y2);
 #ifdef PRINTER_DEBUG
 	cairo_save (cr);
-	dash [0] = 10.0;
-	dash [1] = 10.0;
+	dash[0] = 10.0;
+	dash[1] = 10.0;
 	cairo_set_source_rgb (cr, .5, .5, .5);
 	cairo_set_line_width (cr, .3);
 	cairo_set_dash (cr, 2, dash, .0);
@@ -222,8 +222,8 @@ draw_line (HTMLPainter *painter,
 	   gint x2, gint y2)
 {
 	HTMLPrinter *printer;
-	double printer_x1, printer_y1;
-	double printer_x2, printer_y2;
+	gdouble printer_x1, printer_y1;
+	gdouble printer_x2, printer_y2;
 	cairo_t *cr;
 
 	printer = HTML_PRINTER (painter);
@@ -273,12 +273,12 @@ draw_border (HTMLPainter *painter,
 	#define DARK(c)  dark.c = MAX (((gint) bg->c) - INC, 0)
 	#define LIGHT(c) light.c = MIN (((gint) bg->c) + INC, 0xffff)
 
-	DARK(red);
-	DARK(green);
-	DARK(blue);
-	LIGHT(red);
-	LIGHT(green);
-	LIGHT(blue);
+	DARK (red);
+	DARK (green);
+	DARK (blue);
+	LIGHT (red);
+	LIGHT (green);
+	LIGHT (blue);
 
 	switch (style) {
 	case HTML_BORDER_SOLID:
@@ -392,15 +392,13 @@ static void
 draw_pixmap (HTMLPainter *painter, GdkPixbuf *pixbuf, gint x, gint y, gint scale_width, gint scale_height, const GdkColor *color)
 {
 	HTMLPrinter *printer;
-	double print_x, print_y;
-	double print_scale_width, print_scale_height;
-	double page_height;
+	gdouble print_x, print_y;
+	gdouble print_scale_width, print_scale_height;
 	cairo_t *cr;
 
 	printer = HTML_PRINTER (painter);
 	g_return_if_fail (printer->context != NULL);
 	cr = gtk_print_context_get_cairo_context (printer->context);
-	page_height =(double) gtk_print_context_get_height (printer->context);
 	print_x = SCALE_ENGINE_TO_GNOME_PRINT (x);
 	print_y = SCALE_ENGINE_TO_GNOME_PRINT (y);
 	print_scale_width  = SCALE_ENGINE_TO_GNOME_PRINT (scale_width);
@@ -416,8 +414,8 @@ static void
 fill_rect (HTMLPainter *painter, gint x, gint y, gint width, gint height)
 {
 	HTMLPrinter *printer;
-	double printer_x, printer_y;
-	double printer_width, printer_height;
+	gdouble printer_x, printer_y;
+	gdouble printer_width, printer_height;
 	cairo_t *cr;
 
 	printer = HTML_PRINTER (painter);
@@ -450,9 +448,9 @@ draw_lines (HTMLPrinter *printer, double x, double y, double width, PangoAnalysi
 	cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 
 	if (properties->underline) {
-		double thickness = pango_units_to_double (pango_font_metrics_get_underline_thickness (metrics));
-		double position = pango_units_to_double (pango_font_metrics_get_underline_position (metrics));
-		double ly = y + position - thickness / 2;
+		gdouble thickness = pango_units_to_double (pango_font_metrics_get_underline_thickness (metrics));
+		gdouble position = pango_units_to_double (pango_font_metrics_get_underline_position (metrics));
+		gdouble ly = y + position - thickness / 2;
 
 		cairo_new_path (cr);
 		cairo_move_to (cr, x, ly + 4);
@@ -462,9 +460,9 @@ draw_lines (HTMLPrinter *printer, double x, double y, double width, PangoAnalysi
 	}
 
 	if (properties->strikethrough) {
-		double thickness = pango_units_to_double (pango_font_metrics_get_strikethrough_thickness (metrics));
-		double position = pango_units_to_double (pango_font_metrics_get_strikethrough_position (metrics));
-		double ly = y + position - thickness / 2;
+		gdouble thickness = pango_units_to_double (pango_font_metrics_get_strikethrough_thickness (metrics));
+		gdouble position = pango_units_to_double (pango_font_metrics_get_strikethrough_position (metrics));
+		gdouble ly = y + position - thickness / 2;
 
 		cairo_new_path (cr);
 		cairo_move_to (cr, x, ly - 8);
@@ -532,7 +530,7 @@ static void
 draw_embedded (HTMLPainter *p, HTMLEmbedded *o, gint x, gint y)
 {
 	gdouble print_x, print_y;
-	HTMLPrinter *printer = HTML_PRINTER(p);
+	HTMLPrinter *printer = HTML_PRINTER (p);
 	GtkWidget *embedded_widget;
 	cairo_t *cr;
 
@@ -543,9 +541,9 @@ draw_embedded (HTMLPainter *p, HTMLEmbedded *o, gint x, gint y)
 	cairo_save (cr);
 	cairo_translate (cr,
 			print_x, print_y + o->height * PIXEL_SIZE);
-	embedded_widget = html_embedded_get_widget(o);
+	embedded_widget = html_embedded_get_widget (o);
 	if (embedded_widget && GTK_IS_HTML_EMBEDDED (embedded_widget)) {
-		g_signal_emit_by_name(G_OBJECT (embedded_widget),
+		g_signal_emit_by_name (G_OBJECT (embedded_widget),
 				      "draw_print",
 				       cr);
 	}
@@ -677,7 +675,7 @@ html_printer_new (GtkWidget *widget, GtkPrintContext *context)
 guint
 html_printer_get_page_width (HTMLPrinter *printer)
 {
-	double printer_width;
+	gdouble printer_width;
 	guint engine_width;
 
 	g_return_val_if_fail (printer != NULL, 0);
@@ -692,7 +690,7 @@ html_printer_get_page_width (HTMLPrinter *printer)
 guint
 html_printer_get_page_height (HTMLPrinter *printer)
 {
-	double printer_height;
+	gdouble printer_height;
 	guint engine_height;
 
 	g_return_val_if_fail (printer != NULL, 0);
